const path = require('path');
const merge = require('lodash/merge');
const aliases = require('./constants/aliases');

module.exports = function(config, { defaultLoaders }) {
  config.resolve.alias = merge(config.resolve.alias, aliases);

  config.module.rules.push({
    test: /\.md$/,
    loader: require.resolve('@politico/markdown-react-loader'),
  });

  config.module.rules.push({
    test: /\.txt$/,
    loader: path.resolve(__dirname, 'loaders/text.js'),
  });

  config.module.rules.push({
    test: /\/theme\/*\.css$/,
    use: [
      defaultLoaders.babel,
      {
        loader: require('styled-jsx/webpack').loader,
        options: {
          type: (fileName, options) => options.query.type || 'global',
        },
      },
    ],
  });

  config.module.rules.push({
    test: /theme.*\.scss$/,
    use: [
      defaultLoaders.babel,
      {
        loader: require('styled-jsx/webpack').loader,
        options: {
          type: (fileName, options) => options.query.type || 'global',
        },
      },
      'sass-loader',
    ],
  });

  config.module.rules.push({
    test: /\.module\.scss$/,
    use: [
      defaultLoaders.babel,
      {
        loader: require('styled-jsx/webpack').loader,
        options: {
          type: (fileName, options) => options.query.type || 'scoped',
        },
      },
      'sass-loader',
    ],
  });

  config.module.rules.push({
    test: /\.scss$/,
    exclude: [
      /module/,
      /theme.*\.s?css$/,
    ],
    use: [
      defaultLoaders.babel,
      {
        loader: require('styled-jsx/webpack').loader,
        options: {
          type: (fileName, options) => options.query.type || 'scoped',
        },
      },
      'sass-loader',
    ],
  });

  return config;
};
