import { useState, useCallback, useEffect } from 'react';
import classnames from 'classnames';
import randomstring from 'randomstring';

import stylesheet from './styles.module.scss';

const Ad = props => {
  const { type, classes } = props;
  const [id, setId] = useState(null);

  const {
    container: containerClass,
    root: rootClass,
    disclaimer: disclaimerClass,
  } = classes;

  const mountAd = useCallback(() => {
    if (id && window.generateCustomAds) {
      window.generateCustomAds(`#${id}`, type);
      return true;
    } else {
      return false;
    }
  }, [id, type]);

  useEffect(() => {
    const idNum = randomstring.generate({
      length: 12,
      charset: 'alphabetic',
    });

    setId(`ad-${idNum}`);
  }, [type]);

  useEffect(() => {
    const waiting = setInterval(() => {
      const success = mountAd();
      if (success) {
        clearInterval(waiting);
      }
    }, 2000);

    return () => {
      clearInterval(waiting);
    };
  }, [mountAd]);

  return (
    <div className={classnames('PibAd-container', 'content-group', 'screenshot-remove', containerClass)}>
      <p className={classnames('PibAd-disclaimer', disclaimerClass)}>
        Advertisement
      </p>
      <div id={id} className={classnames('PibAd-root', 'ad-slot', 'flex', 'horizontal', rootClass)} />
      <style jsx>{stylesheet}</style>
    </div>
  );
};

Ad.defaultProps = {
  type: 'supercube',
  classes: {},
};

export default Ad;
