import classnames from 'classnames';

import useFbHandler from './hooks/useFbHandler';
import useMailHandler from './hooks/useMailHandler';
import useNavigator from './hooks/useNavigator';
import useShareMeta from './hooks/useShareMeta';
import useTwitterHandler from './hooks/useTwitterHandler';

import stylesheet from './styles.module.scss';

const Share = props => {
  const { classes } = props;
  const meta = useShareMeta(props);
  const triggerNavigator = useNavigator(meta);

  const opts = {
    meta,
    props,
    triggerNavigator,
  };

  const fbHandler = useFbHandler({ handler: props.onFb, ...opts });
  const twitterHandler = useTwitterHandler({ handler: props.onTwitter, ...opts });
  const mailHandler = useMailHandler({ handler: props.onMail, ...opts });

  const {
    root: rootClass,
    button: buttonClass,
  } = classes;

  return (
    <div className={classnames('PibShare_root', 'share-buttons', rootClass)}>
      <button
        className={classnames('PibShare-button', 'bt-icon', 'custom-icon--facebook', buttonClass)}
        onClick={fbHandler}
      >
        <svg version='1.1' xmlns='http://www.w3.org/2000/svg' xlinkHref='http://www.w3.org/1999/xlink' width='14' height='14' fill='white' viewBox='0 0 15 15'>
          <path d='M9.229 15.988h-3.305v-7.989h-1.652v-2.754h1.652v-1.653c0-2.246 0.932-3.582 3.581-3.582h2.206v2.754h-1.378c-1.031 0-1.1 0.385-1.1 1.103l-0.004 1.378h2.498l-0.292 2.754h-2.206v7.989z' />
        </svg>
      </button>

      <button
        className={classnames('PibShare-button', 'bt-icon', 'bt-icon--twitter', buttonClass)}
        onClick={twitterHandler}
      />

      <button
        className={classnames('PibShare-button', 'bt-icon', 'bt-icon--mail', buttonClass)}
        onClick={mailHandler}
      />
      <style jsx>{stylesheet}</style>
    </div>
  );
};

Share.defaultProps = {
  subject: '',
  body: '',
  onFb: () => {},
  onTwitter: () => {},
  onMail: () => {},
  classes: {},
};

export default Share;
