export default {
  title: 'Typography',

  importString: `\
import { H1, H2, H3, H4, H5, H6, P, Base } from '@politico/interactive-style/lib/Typography';
// or
import { Typography } from '@politico/interactive-style';
const { H1, H2, H3, H4, H5, H6, P, Base } = Typography`,

  componentProps: [
    {
      name: 'children',
      type: 'node',
      description: 'The content of the component',
    },
    {
      name: 'type',
      type: 'string',
      default: '"p"',
      description: 'Set the node type of the root text element (only for Base)',
    },
    {
      name: 'lighter',
      type: 'bool',
      default: 'false',
      description: 'Use a lighter weight (only for h3)',
    },
    {
      name: 'bolder',
      type: 'bool',
      default: 'false',
      description: 'Use a bolder weight (only for h2 and h5)',
    },
    {
      name: 'sans & sans-serif',
      type: 'bool',
      default: 'false',
      description: 'Use a sans-serif font (only for p).',
    },
    {
      name: 'no-margins',
      type: 'bool',
      default: 'false',
      description: 'Remove margins and max widths.',
    },
  ],

  cssProps: [
    {
      name: 'container',
      globalClass: 'PibTypography-container',
      description: 'Styles applied to container div',
    },
    {
      name: 'text',
      globalClass: 'PibTypography-text',
      description: 'Styles applied to root textual element',
    },
  ],

  examples: [
    {
      code: `
<H1>
  The quick brown fox jumps over the lazy dog
</H1>`,
    },

    {
      name: 'Weight Variants',
      description: 'Some elements have "lighter" or "bolder" weight elements you can toggle.',
      code: `
<div>
  <H2>
    The quick brown fox
  </H2>
  <H2 bolder>
    jumps over the lazy dog
  </H2>
  <hr />
  <H3>
    The quick brown fox
  </H3>
  <H3 lighter>
    jumps over the lazy dog
  </H3>
</div>
`,
    },

    {
      name: 'Custom Margins',
      description: 'If you want custom margins, you may want to remove the built-in margins and max-widths. You can do that by using the "no-margins" prop. Try removing the prop to see the defualt behavior.',
      code: `
<P no-margins>
    Add the "no-margins" prop to break outside the well.
</P>
`,
    },

    {
      name: 'Custom Root Element',
      description: 'Most of the common root elements have their own shorthand (e.g. "H1", "H2", "P"). If you\'d like to overwrite that root element you can use the "Base" component and supply a "type" prop. Try changing the root element to something else.',
      code: `
<Typography.Base type='code'>
  Custom types in Typography
</Typography.Base >
`,
    },
  ],
};
