import pkg from 'package.json';
import classnames from 'classnames';
import getConfig from 'next/config';
import { useRouter } from 'next/router';
import Link from 'Common/Link';

import stylesheet from './styles.module.scss';

const { publicRuntimeConfig } = getConfig();
const { components } = publicRuntimeConfig;

const SiteNav = props => {
  const router = useRouter();

  const active = router.route === '/' ? null :
    router.route === '/colors' ? 'colors' :
      router.query.name;

  return (
    <div className='site-navigation'>
      <div className='site-navigation-inner'>
        <h1 className='project-name'>
          <span className='app-name'>
            <Link page='root'>
              <b className='bt-icon bt-icon--politico' /> <br />
              <span className='app-name-inner'>Interactive Style</span>
            </Link>
          </span>
        </h1>
        <p className='version'>
          <a href='https://www.npmjs.com/package/@politico/interactive-style'>
          v{pkg.version}
          </a>
        </p>
        <ul className='pages'>
          <li>
            <Link page='colors'>
              <span className={classnames('page', { active: active === 'colors' })}>
                Colors
              </span>
            </Link>
          </li>
          <li>
            <span className='page__container'>
              Components
            </span>
          </li>
          <ul className='pages__components'>
            {components.map(component =>
              <li key={component}>
                <Link page='component' name={component}>
                  <span className={classnames('page', 'page__inner', { active: active === component })}>
                    {component}
                  </span>
                </Link>
              </li>
            )}
          </ul>
        </ul>
      </div>
      <style jsx>{stylesheet}</style>
    </div>
  );
};

export default SiteNav;
